@@ -81,7 +81,7 @@ THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
 
 =head1 SEE ALSO
 
-L<Business::OnlinePayment>, http://420.am/business-onlinepayment
+L<Business::OnlinePayment>, http://perl.business/onlinepayment
 
 
 =cut
